var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/*
 * This file is part of the nivo project.
 *
 * Copyright 2016-present, Raphaël Benitte.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
import React, { Component } from 'react';
import _ from 'lodash-es';
import PropTypes from 'prop-types';
import { merge } from 'lodash-es';
import { Motion, TransitionMotion, spring } from 'react-motion';
import Nivo, { defaultTheme } from '../../../Nivo';
import { margin as marginPropType, motion as motionPropTypes } from '../../../PropTypes';
import { getColorsGenerator } from '../../../ColorUtils';
import { degreesToRadians } from '../../../ArcUtils';
import SvgWrapper from '../SvgWrapper';
import * as d3 from 'd3';

var Pie = function (_Component) {
    _inherits(Pie, _Component);

    function Pie() {
        _classCallCheck(this, Pie);

        return _possibleConstructorReturn(this, _Component.apply(this, arguments));
    }

    Pie.prototype.render = function render() {
        var _props = this.props,
            data = _props.data,
            _margin = _props.margin,
            _width = _props.width,
            _height = _props.height,
            _innerRadius = _props.innerRadius,
            _padAngle = _props.padAngle,
            cornerRadius = _props.cornerRadius,
            _theme = _props.theme,
            colors = _props.colors,
            colorBy = _props.colorBy,
            animate = _props.animate,
            motionStiffness = _props.motionStiffness,
            motionDamping = _props.motionDamping;


        var margin = Object.assign({}, Nivo.defaults.margin, _margin);
        var width = _width - margin.left - margin.right;
        var height = _height - margin.top - margin.bottom;
        var centerX = width / 2;
        var centerY = height / 2;

        var padAngle = degreesToRadians(_padAngle);

        var theme = merge({}, defaultTheme, _theme);
        var color = getColorsGenerator(colors, colorBy);

        var motionProps = {
            animate: animate,
            motionDamping: motionDamping,
            motionStiffness: motionStiffness
        };

        var radius = 160;
        var innerRadius = radius * Math.min(_innerRadius, 1);

        var pie = d3.pie();
        pie.value(function (d) {
            return d.value;
        });

        var arc = d3.arc();
        arc.outerRadius(160);

        return React.createElement(
            SvgWrapper,
            { width: _width, height: _height, margin: margin },
            React.createElement(
                Motion,
                {
                    style: {
                        centerX: spring(centerX, motionProps),
                        centerY: spring(centerY, motionProps),
                        innerRadius: spring(innerRadius),
                        padAngle: spring(padAngle, motionProps),
                        cornerRadius: spring(cornerRadius, motionProps)
                    }
                },
                function (interpolatingStyle) {
                    var interpolatedPie = pie.padAngle(interpolatingStyle.padAngle);
                    var interpolatedArc = arc.cornerRadius(interpolatingStyle.cornerRadius).innerRadius(interpolatingStyle.innerRadius);

                    return React.createElement(
                        'g',
                        {
                            transform: 'translate(' + interpolatingStyle.centerX + ', ' + interpolatingStyle.centerY + ')'
                        },
                        interpolatedPie(data).map(function (d) {
                            return React.createElement('path', {
                                key: d.data.id,
                                d: interpolatedArc(d),
                                fill: color(d.data)
                            });
                        })
                    );
                }
            )
        );
    };

    return Pie;
}(Component);

Pie.propTypes = _extends({
    data: PropTypes.arrayOf(PropTypes.shape({
        id: PropTypes.string.isRequired,
        value: PropTypes.number.isRequired,
        label: PropTypes.string
    })).isRequired,

    // dimensions
    width: PropTypes.number.isRequired,
    height: PropTypes.number.isRequired,
    margin: marginPropType,

    innerRadius: PropTypes.number.isRequired,
    padAngle: PropTypes.number.isRequired,
    cornerRadius: PropTypes.number.isRequired,

    // theming
    theme: PropTypes.object.isRequired,
    colors: PropTypes.any.isRequired,
    colorBy: PropTypes.oneOfType([PropTypes.string, PropTypes.func])

}, motionPropTypes);
Pie.defaultProps = {
    // dimensions
    margin: Nivo.defaults.margin,

    innerRadius: 0,
    padAngle: 0,
    cornerRadius: 0,

    // theming
    theme: {},
    colors: Nivo.defaults.colorRange,
    colorBy: 'id',

    // motion
    animate: true,
    motionStiffness: Nivo.defaults.motionStiffness,
    motionDamping: Nivo.defaults.motionDamping
};
export default Pie;